#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/8/4 9:40 上午
# @Author   : xuxiang
# @Project  : PythonSDK
# @File     : __init__.py
# @Software : PyCharm


from XuXiangPythonSDK import FileReadWrite



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/7/6 10:33 上午
# @Author   : xuxiang
# @Project  : 报表
# @File     : Log.py
# @Software : PyCharm

import logging
import sys
import os
# from logging.handlers import HTTPHandler
from logging.handlers import RotatingFileHandler

logger = logging.getLogger(__name__)
logger.setLevel(level=logging.DEBUG)

# StreamHandler
stream_handler = logging.StreamHandler(sys.stdout)
stream_handler.setLevel(level=logging.DEBUG)
stream_formatter = logging.Formatter('%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s - %(message)s')
stream_handler.setFormatter(stream_formatter)
logger.addHandler(stream_handler)

# FileHandler
# file_handler = logging.FileHandler('报表日志.log')
# file_handler.setLevel(level=logging.INFO)
# file_formatter = logging.Formatter('%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s - %(message)s')
# file_handler.setFormatter(file_formatter)
# logger.addHandler(file_handler)

# RotatingFileHandler
path = os.getcwd()+'/报表日志'
if not os.path.exists(path):
    os.makedirs(path)
rotating_file_handler = RotatingFileHandler('报表日志/报表日志.log', maxBytes=1024*1024, backupCount=3)
rotating_file_handler.setLevel(level=logging.ERROR)
file_formatter = logging.Formatter('%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s - %(message)s')
rotating_file_handler.setFormatter(file_formatter)
logger.addHandler(rotating_file_handler)


# HTTPHandler
# 需要先启动HTTP Server并运行在8001端口
# http_handler = HTTPHandler(host='localhost:8001', url='log', method='POST')
# http_handler.setLevel(level=logging.INFO)
# logger.addHandler(http_handler)










'''
1、导入模块
2、使用yagmail的类创建对象（发件人，发件人授权码，发件服务器）
3、使用yagmail对象发送邮件（指定收件人，邮件主题，发送内容）
'''

#1、导入模块
import yagmail
import os

class SendEmail:
    # sender 发件人邮箱
    # password #邮箱授权码,通过在邮箱设置里面可查到
    # host 发件服务器 例如 smtp.qq.com
    def __init__(self, sender, password, host):
        self.ya_obj = yagmail.SMTP(user=sender, password=password, host=host)

    # receiver 收件人邮箱 'xxxxxxxx'，也可写成列表形式["xxxxxxxxx"]，收件人有多个则造成一个列表
    # subject 主题，
    # contents 内容
    # attachments 附件 #附件为列表形式，填入具体路径
    def send(self, receiver, subject=None, contents=None, attachments=None):
        try:
            self.ya_obj.send(to=receiver, subject=subject, contents=contents, attachments=attachments)
        except Exception as e:
            print('发送邮件出错:', e)


if __name__ == "__main__":
    se = SendEmail(sender='1456127594@qq.com', password='wfnnyzdkgbwpfjjc', host='smtp.qq.com')

    # 发送无主题无内容无附件邮件
    se.send('xu_xiang_1@163.com')

    # 发送有主题无内容无附件邮件
    se.send('xu_xiang_1@163.com', subject='有主题无内容无附件邮件')

    # 发送无主题有内容无附件的邮件
    se.send('xu_xiang_1@163.com', contents='无主题有内容无附件')

    # 发送有主题有内容无附件的邮件
    se.send('xu_xiang_1@163.com', subject='有主题有内容无附件', contents='测试一下')

    # 发送有主题有内容有附件的邮件
    se.send('xu_xiang_1@163.com',subject='有主题有内容有附件的邮件', contents='测试一下', attachments=r'/Users/xuxiang/Pictures/5302d3ac48b09.jpg')

    # 发送有图片内容的邮件
    se.send('xu_xiang_1@163.com', subject='有图片内容的邮件', contents=['测试一下',yagmail.inline(r'/Users/xuxiang/Pictures/5302d3ac48b09.jpg')])




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/2/23 9:45 上午
# @Author   : xuxiang
# @Project  : XuXiangPythonLibrary
# @File     : CornJobs.py
# @Software : PyCharm

# 定时任务

from apscheduler.schedulers.blocking import BlockingScheduler
from apscheduler.schedulers.background import BackgroundScheduler
import datetime

class CronJob():
    # func 执行作业
    # trigger 触发方式 date,指定时间点，触发一次，interval,指定间隔时间，周期性执行，cron,在指定时间内，定期执行

    # 主线程运行，会阻塞主线程
    # func 执行作业
    # trigger 触发方式 date,指定时间点，触发一次，interval,指定间隔时间，周期性执行，cron,在指定时间内，定期执行

    # date触发方式的参数
    # run_date, 准确的执行时间，例如'2018-09-21 15:53:00' date(2009, 11, 6)  datetime(2009, 11, 6, 16, 30, 5)
    # run_date (datetime|str) – the date/time to run the job at
    # timezone (datetime.tzinfo|str) – time zone for run_date if it doesn’t have one already

    # interval触发方式的参数
    # interval, 间隔时间
    # weeks (int) – number of weeks to wait
    # days (int) – number of days to wait
    # hours (int) – number of hours to wait
    # minutes (int) – number of minutes to wait
    # seconds (int) – number of seconds to wait
    # start_date (datetime|str) – starting point for the interval calculation
    # end_date (datetime|str) – latest possible date/time to trigger on
    # timezone (datetime.tzinfo|str) – time zone to use for the date/time calculations

    # cron触发方式的参数
    # year (int|str) – 4-digit year
    # month (int|str) – month (1-12)
    # day (int|str) – day of the (1-31)
    # week (int|str) – ISO week (1-53)
    # day_of_week (int|str) – number or name of weekday (0-6 or mon,tue,wed,thu,fri,sat,sun)
    # hour (int|str) – hour (0-23)
    # minute (int|str) – minute (0-59)
    # second (int|str) – second (0-59)
    # start_date (datetime|str) – earliest possible date/time to trigger on (inclusive)
    # end_date (datetime|str) – latest possible date/time to trigger on (inclusive)
    # timezone (datetime.tzinfo|str) – time zone to use for the date/time calculations (defaults to scheduler timezone)

    # cron方式的表达式
    # Expression    Field   Description
    # *             any     每到*执行一次
    # */a           any     从最小值开始，每隔一个a值执行一次
    # a-b           any     在a-b范围内的任何值上执行（a必须小于b）
    # a-b/c         any     在a-b范围内每c值执行一次
    # xth y         day     本月内工作日y的第x次执行
    # last x        day     本月内最后一个工作日x执行
    # last          day     本月内最后一天执行
    # x,y,z         any     激发任何匹配的表达式；可以组合任意数量的上述表达式

    def blockingScheduler(self, func, trigger, id=None, name=None, *args, **kwargs):
        # BlockingScheduler：在进程中运行单个任务，调度器是唯一运行的东西
        scheduler = BlockingScheduler()
        # 采用阻塞的方式

        scheduler.add_job(func, trigger=trigger, id=id, name=name, misfire_grace_time=600, *args, **kwargs)

        scheduler.start()

    # 后台执行
    def backgroundScheduler(self, func, trigger, id=None, name=None, *args, **kwargs):
        # BackgroundScheduler: 适合于要求任何在程序后台运行的情况，当希望调度器在应用后台执行时使用。
        scheduler = BackgroundScheduler()
        # 采用非阻塞的方式

        scheduler.add_job(func, trigger=trigger, id=id, name=name, misfire_grace_time=600, *args, **kwargs)
        # 这是一个独立的线程
        scheduler.start()






#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/1/21 1:33 下午
# @Author   : xuxiang
# @Project  : XuXiangPythonLibrary
# @File     : Request.py
# @Software : PyCharm

# 网络请求方法

import requests
from requests import adapters
import urllib3
from XuXiangPythonSDK.Log import logger


class Request:
    session = requests.Session()
    session.keep_alive = False
    requests.adapters.DEFAULT_RETRIES = 5
    urllib3.disable_warnings()

    # Get请求数据
    # 如果要传入form数据，需要转换成json字符串 data=json.dumps(FormData)
    def getData(self, url, params=None, **kwargs):
        try:
            response = requests.get(url=url, params=params, **kwargs)
            response.raise_for_status()
            return response.json()
        except Exception as e:
            logger.error('Get网络请求异常：', e)

    # Post传递表单数据，当前接口的请求类型为application/x-www-form-urlencoded
    # 如果当前请求类型为application/json，仍然想用data传参，需要将字典类型数据转换为json字符串， data=json.dumps(params)
    def postFormData(self, url, data=None, **kwargs):
        try:
            response = requests.post(url=url, data=data, **kwargs)
            response.raise_for_status()
            return response.json()
        except Exception as e:
            logger.error('PostFormData异常：', e)


    #  Post传递json数据，当前接口的请求类型为application/json
    def postJsonData(self, url, json=None, **kwargs):
        try:
            response = requests.post(url=url, json=json, **kwargs)
            response.raise_for_status()
            return response.json()
        except Exception as e:
            logger.error('PostJsonData异常：', e)











#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/3/13 3:41 下午
# @Author   : xuxiang
# @Project  : DingTalk
# @File     : DingTalk.py
# @Software : PyCharm

from XuXiangPythonSDK.Request import Request
import time
import urllib.parse
import urllib.request
import hmac
import base64
import hashlib
from XuXiangPythonSDK.Log import logger

class DingTalk:
    # url:创建机器人时生成的Webhook
    # secret:创建机器人时选择加签，生成的秘钥
    def __init__(self, url:str, secret:str=''):
        self.request = Request()

        timestamp = round(time.time()*1000) #时间戳
        secret_enc = secret.encode('utf8')
        string_to_sign = '{}\n{}'.format(timestamp, secret)
        string_to_sign_enc = string_to_sign.encode('utf-8')
        hmac_code = hmac.new(secret_enc, string_to_sign_enc, digestmod=hashlib.sha256).digest()
        sign = urllib.parse.quote_plus(base64.b64encode(hmac_code))  # 最终签名


        self.webhook_url = url + '&timestamp={}&sign={}'.format(timestamp, sign)  # 最终url，url+时间戳+签名

    # 发送文本消息
    # msg_content:String 消息内容
    # atAll:Bool 是否@所有人
    # atMobiles:List 被@人的手机号 在content里添加被@人的手机号
    def send_text_msg(self, content, atAll=False, atMobiles=None):

        headers = {'Content-Type': 'application/json;charset=utf-8'}
        data = {
            "msgtype":"text",
            "text":{
                "content":content
            },
            'at':{
                'atMobiles':atMobiles,
                'isAtAll':atAll
            }

        }

        res = self.request.postJsonData(self.webhook_url, json=data, headers=headers)
        if res['errcode'] == 0:
            logger.info('钉钉消息发送成功')
        else:
            logger.error('钉钉消息发送失败',res['errmsg'])

    # 发送链接消息
    # text: String 消息内容
    # title:String 消息标题
    # picUrl:String 图片url
    # messageUrl:String 点击消息跳转的url 以http开头
    # msg_content:String 消息内容
    def send_link_msg(self,title, text, messageUrl, picUrl=None):
        headers = {'Content-Type': 'application/json;charset=utf-8'}
        data = {
            "msgtype": "link",
            "link": {
                'text':text,
                'title':title,
                'picUrl':picUrl,
                'messageUrl':messageUrl
            }
        }

        res = self.request.postJsonData(self.webhook_url, json=data, headers=headers)
        if res['errcode'] == 0:
            logger.info('钉钉消息发送成功')
        else:
            logger.error('钉钉消息发送失败', res['errmsg'])

    # 发送markdown消息
    # title:String 列表中展示的消息标题
    # text:String markdown格式的消息
    def send_markdown_msg(self, title, text):
        headers = {'Content-Type': 'application/json;charset=utf-8'}
        data = {
            "msgtype": "markdown",
            "markdown": {
                'text': text,
                'title': title,
            }
        }

        res = self.request.postJsonData(self.webhook_url, json=data, headers=headers)
        if res['errcode'] == 0:
            logger.info('钉钉消息发送成功')
        else:
            logger.error('钉钉消息发送失败', res['errmsg'])


    # 发送ActionCard消息
    # title:String 列表中展示的消息标题
    # text:String markdown格式的消息
    # singleTitle:String 单个按钮的标题，设置此项和singleURL后btns无效
    # singleUrl:String 点击singleTitle按钮触发的URL
    # btns:List 按钮数组 里面存放{'title': title, 'actionURL': URL}
    # btnOrientation:String 0-按钮竖直排列，1-按钮横向排列
    def send_actionCard_msg(self, title, text, singleTitle=None, singleUrl=None, btns=None, btnOrientation='0'):
        headers = {'Content-Type': 'application/json;charset=utf-8'}
        data = {
            "msgtype": "actionCard",
            "actionCard": {
                'text': text,
                'title': title,
                'singleTitle':singleTitle,
                'singleUrl':singleUrl,
                'btn':btns,
                'btnOrientation': btnOrientation
            }
        }

        res = self.request.postJsonData(self.webhook_url, json=data, headers=headers)
        if res['errcode'] == 0:
            logger.info('钉钉消息发送成功')
        else:
            logger.error('钉钉消息发送失败',res['errmsg'])

    # 发送FeedCard消息
    # links:List 存放{'title': title, 'messageURL': messageURL, 'picURL': picURL}
    # title:String 单条消息标题
    # messageURL:String 点击单条消息跳转的链接
    # picURL:String 单条消息的图片URL
    def send_feedCard_msg(self, links):
        headers = {'Content-Type': 'application/json;charset=utf-8'}
        data = {
            "msgtype": "feedCard",
            "feedCard": {
                'links': links,

            }
        }

        res = self.request.postJsonData(self.webhook_url, json=data, headers=headers)
        if res['errcode'] == 0:
            logger.info('钉钉消息发送成功')
        else:
            logger.error('钉钉消息发送失败', res['errmsg'])



if __name__ == "__main__":


    msg_content = '啊啊啊'
    text = '这是内容'
    title = '这是标题'
    picUrl = 'https://t7.baidu.com/it/u=3587945189,2578428673&fm=193&f=GIF'
    messageUrl = 'https://www.baidu.com'

    url = 'https://oapi.dingtalk.com/robot/send?access_token=8d6f66b4c8cb1d6a896f6dca8dc41881ac119dc4f17f6a1841b285ac82e6b6b4'
    secret = 'SEC817cca514e4907cc8e7fd01f6c10f36e07ca5132b46bc2b40d082d94ba040770'
    url2= 'https://oapi.dingtalk.com/robot/send?access_token=c55f831c6638003d7d7b2f407354c4b39c673579b399456589ebac626c5ac95f'
    dt = DingTalk(url=url, secret=secret)
    dt.send_link_msg(title=title, text=text, messageUrl=messageUrl)





#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/2/4 3:44 下午
# @Author   : xuxiang
# @Project  : XuXiangPythonLibrary
# @File     : FileReadWrite.py
# @Software : PyCharm

class FileReadWrite:
    # mode
    # r 只读，不能创建文件
    # r+ 读写，不能创建文件，写入时插入到原有内容开头，会从头覆盖部分原有内容，覆盖长度和新写入的内容相同
    # rb，只读，不能创建文件，以二进制读取
    # w 只写，可以创建文件，写入会全部覆盖原有内容
    # wb 只写，可以创建文件，写入会全部覆盖原有内容，以二进制写入
    # a 追加写入，可以创建文件，写入时追加到原有内容后面
    # ab 追加写入，可以创建文件，写入时追加到原有内容后面，以二进制写入



    def __init__(self, file, mode):

        try:
            self.file = open(file=file, mode=mode)

        except Exception as e:
            print('以{}模式打开文件{}出错，原因：{}'.format(mode,file, e))


    # 读取文件
    def read(self):
        return self.file.read()

    # 写入文件
    def write(self, content):
        self.file.write(content)

    # 关闭文件
    def close(self):
        self.file.close()








#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/2/7 9:48 上午
# @Author   : xuxiang
# @Project  : XuXiangPythonLibrary
# @File     : DefaultProgramOpenDirOrFile.py
# @Software : PyCharm

import platform
import os
import subprocess

def openDir(dirPath):
    # 打开文件夹
    if platform.system() == "Windows":
        os.startfile(dirPath)
    elif platform.system() == "Darwin":
        subprocess.Popen(["open", dirPath])
    else:
        subprocess.Popen(["xdg-open", dirPath])


def openFile(filePath):
    # 用默认程序打开文件
    if platform.system() == "Windows":
        os.startfile(filePath)
    elif platform.system() == "Darwin":
        subprocess.call(["open", filePath])
    else:
        subprocess.call(["xdg-open", filePath])



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/1/25 3:32 下午
# @Author   : xuxiang
# @Project  : XuXiangPythonLibrary
# @File     : DataBaseManager.py
# @Software : PyCharm

import pymysql
from dbutils.pooled_db import PooledDB
from XuXiangPythonSDK.Log import logger


class DataBaseManager:
    # 初始化对象
    def __init__(self, host, user, password, dbname, port=3306, charset='utf8', use_unicode=True):
        self.pool = self.mysql_connection(host=host, user=user, password=password, dbname=dbname, port=port,
                                          charset=charset, use_unicode=use_unicode)

    # 连接数据库
    def mysql_connection(self, host, user, password, dbname, port=3306, charset='utf8', use_unicode=True):
        pool = PooledDB(
            creator=pymysql,
            maxconnections=0,   # 最大连接数 0和None表示不限制
            mincached=4,        # 初始化时，链接池中至少创建的空闲的链接，0表示不创建
            maxcached=0,        # 链接池中最多闲置的链接，0和None不限制
            blocking=False,     # 连接池中如果没有可用连接后，是否阻塞等待。True，等待；False，不等待然后报错
            host=host,
            port=port,
            user=user,
            passwd=password,
            db=dbname,
            charset=charset,
            use_unicode=use_unicode,
        )
        return pool

    # 新建表 sql="create table tableName(id bigint (255) primary key auto_increment not null ,name varchar (255)not null,age int (255) not null)"
    def create_table(self, sql):
        con = self.pool.connection()
        cur = con.cursor()
        state = False
        try:
            cur.execute(sql)
            state = True
        except Exception as e:
            logger.error(f"数据库新建表操作有误，原因：{e}")
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 清空表数据
    def clear_table(self, tablename):
        con = self.pool.connection()
        cur = con.cursor()
        sql = f"truncate table {tablename}"
        state = False
        try:
            cur.execute(sql)
            state = True
        except Exception as e:
            logger.error(f"数据库清空表操作有误，原因：{e}")
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 删除表数据和表结构
    def delete_table(self, table_name):
        con = self.pool.connection()
        cur = con.cursor()
        sql = f"drop table {table_name}"
        state = False
        try:
            cur.execute(sql)
            state = True
        except Exception as e:
            logger.error(f"数据库删除表操作有误，原因：{e}")
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 复制表结构到新表
    def copy_table(self, new_table_name, old_table_name):
        con = self.pool.connection()
        cur = con.cursor()
        sql = "create table {} like {}".format(new_table_name, old_table_name)
        state = False
        try:
            cur.execute(sql)
            state = True
        except Exception as e:
            logger.error(f"数据库复制表结构操作有误，原因：{e}")
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 复制表结构和数据到新表
    def copy_table_and_data(self, new_table_name, old_table_name):
        con = self.pool.connection()
        cur = con.cursor()
        sql = "create table {} select * from {}".format(new_table_name, old_table_name)
        state = False
        try:
            cur.execute(sql)
            state = True
        except Exception as e:
            logger.error(f"数据库复制表结构和数据操作有误，原因：{e}")
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 复制表数据到新表（新表已有字段，并和旧表结构一样）
    def copy_table_data(self, new_table_name, old_table_name):
        con = self.pool.connection()
        cur = con.cursor()
        sql = "insert into {} select * from {}}".format(new_table_name, old_table_name)
        state = False
        try:
            cur.execute(sql)
            state = True
        except Exception as e:
            logger.error(f"数据库复制表数据操作有误，原因：{e}")
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 增加 sql = "insert into tableName (name, age) values (%s, %s)"  values = ('张三', 18)
    def insert_data(self, sql, values=None):
        con = self.pool.connection()
        cur = con.cursor()
        state = False
        try:
            if values:
                cur.execute(sql, values)
            else:
                cur.execute(sql)
            con.commit()
            state = True
        except Exception as e:
            con.rollback()  # 回滚
            logger.error(f"数据库插入数据操作有误，原因：{e}")
            logger.info(values)
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 批量插入数据  "insert into tableName (name, age) values (%s, %s)"  values = [('张三', 18), ('李四', 19), ('王五', 20)]
    def insert_many_data(self, sql, values):
        con = self.pool.connection()
        cur = con.cursor()
        state = False
        try:
            cur.executemany(sql, values)
            con.commit()
            state = True
        except Exception as e:
            con.rollback()  # 回滚
            logger.error(f"数据库批量插入数据操作有误，原因：{e}")
            logger.info(values)
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 删除 values=18 sql="delete from tableName where age > %s"
    def delete_data(self, sql, values=None):
        con = self.pool.connection()
        cur = con.cursor()
        state = False
        try:
            if values:
                cur.execute(sql, values)
            else:
                cur.execute(sql)
            con.commit()
            state = True
        except Exception as e:
            con.rollback()  # 回滚
            logger.error(f"数据库删除数据操作有误，原因：{e}")
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 批量删除 values = (18, 19, 20)
    #         sql = "delete from tableName where age = %s"
    def delete_many_data(self, sql, values):
        con = self.pool.connection()
        cur = con.cursor()
        state = False
        try:
            cur.executemany(sql, values)
            con.commit()
            state = True
        except Exception as e:
            con.rollback()  # 回滚
            logger.error(f"数据库批量删除数据操作有误，原因：{e}")
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 更新 values=('李四', 18)  sql="update tableName set name = %s where age = %s"
    def update_data(self, sql, values=None):
        con = self.pool.connection()
        cur = con.cursor()
        state = False
        try:
            if values:
                cur.execute(sql, values)
            else:
                cur.execute(sql)
            con.commit()
            state = True
        except Exception as e:
            con.rollback()  # 回滚
            logger.error(f"数据库更新数据操作有误，原因：{e}")
            logger.info(values)
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 批量更新 values=[('李四', 18), ('王五',19), ('张三', 20)]  sql="update tableName set name = %s where age = %s"
    def update_many_data(self, sql, values):
        con = self.pool.connection()
        cur = con.cursor()
        state = False
        try:
            cur.executemany(sql, values)
            con.commit()
            state = True
        except Exception as e:
            con.rollback()  # 回滚
            logger.error(f"数据库批量更新数据操作有误，原因：{e}")
            logger.info(values)
            state = False
        finally:
            cur.close()
            con.close()
            return state

    # 查询全部数据 age=18 sql="select * from tableName where age=%s"
    def select_all_data(self, sql, values=None):
        con = self.pool.connection()
        cur = con.cursor()
        result = []
        try:
            if values:
                cur.execute(sql, values)
            else:
                cur.execute(sql)
            result = cur.fetchall()

        except Exception as e:
            logger.error(f"数据库查询全部数据操作有误，原因：{e}")
        finally:
            cur.close()
            con.close()
            return result

    # 查询一条数据 age=18 sql="select * from tableName where age=%s"
    def select_one_data(self, sql, values=None):
        con = self.pool.connection()
        cur = con.cursor()
        result = ()
        try:
            if values:
                cur.execute(sql, values)
            else:
                cur.execute(sql)
            result = cur.fetchone()
        except Exception as e:
            logger.error(f"数据库查询一条数据操作有误，原因：{e}")
        finally:
            cur.close()
            con.close()
            return result

    # 查询指定条数数据 age=18 sql="select * from tableName where age=%s"
    def select_many_data(self, sql, values=None, rows=None):
        con = self.pool.connection()
        cur = con.cursor()
        result = []
        try:
            if values:
                cur.execute(sql, values)
            else:
                cur.execute(sql)
            result = cur.fetchmany(size=rows)

        except Exception as e:
            logger.error(f"数据库查询多条数据操作有误，原因：{e}")
        finally:
            cur.close()
            con.close()
            return result



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/3/2 5:28 下午
# @Author   : xuxiang
# @Project  : ReportUserFriendBindFileDetail
# @File     : DBManagerWithPandas.py
# @Software : PyCharm

import pandas as pd
from pandas import DataFrame
from XuXiangPythonSDK.Log import logger

from sqlalchemy import create_engine


class DBManagerWithPandas(object):
    # 初始化对象
    def __init__(self, host, user, password, dbname, port=3306):
        self.host = host
        self.user = user
        self.password = password
        self.dbname = dbname
        self.port = port

    def getData(self, sql, values=None, chunksize=None):
        conn = create_engine(
            'mysql+pymysql://{user}:{password}@{host}:{port}/{dbname}?charset=utf8'.format(user=self.user,
                                                                                           password=self.password,
                                                                                           host=self.host,
                                                                                           port=self.port,
                                                                                           dbname=self.dbname),
            pool_size=0,  # 连接池数量，无限制

        )
        df = DataFrame()
        try:
            df = pd.read_sql_query(sql=sql, params=values, con=conn, chunksize=chunksize)

        except Exception as e:
            logger.error('Pandas读取数据库失败', e)
            logger.info(sql, values)
        finally:
            conn.dispose()
            return df

    def insertData(self, df: DataFrame, tableName):
        conn = create_engine(
            'mysql+pymysql://{user}:{password}@{host}:{port}/{dbname}?charset=utf8'.format(user=self.user, password=self.password, host=self.host, port=self.port, dbname=self.dbname))
        code = False
        msg = '失败'

        try:
            df.to_sql(tableName, conn, if_exists='append', index=False)
            code = True
            msg = '成功'

        except Exception as e:
            logger.error('Pandas写入数据库失败', e)
            logger.info(tableName)
            code = False
            msg = e

        finally:
            conn.dispose()
            return code, msg



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/2/26 3:39 下午
# @Author   : xuxiang
# @Project  : XuXiangPythonLibrary
# @File     : setup.py
# @Software : PyCharm

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="XuXiangPythonSDK",
    version="0.0.7",
    author="XuXiang",
    author_email="1456127594@qq.com",
    description="我的自用模块",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitee.com/OrlandoXu/XuXiangPythonSDK",
    packages=setuptools.find_packages(),
    install_requires=[
        "apscheduler",
        "pymysql",
        "dbutils",
        "pandas",
        "sqlalchemy",
        "requests",
        "yagmail"

    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)





#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/3/24 3:24 下午
# @Author   : xuxiang
# @Project  : PythonProjects
# @File     : DingTalk2.0.py
# @Software : PyCharm

from XuXiangPythonSDK.Request import Request



class DingTalk2():
    def __init__(self, appkey, appsecret):
        self.request = Request()
        self.appkey = appkey
        self.appsecret = appsecret
        self.access_token = self.getAccess_token()

    def getAccess_token(self):
        url = 'https://oapi.dingtalk.com/gettoken?appkey=%s&appsecret=%s' % (self.appkey, self.appsecret)

        headers = {
            'Content-Type': "application/x-www-form-urlencoded"
        }
        data = {'appkey': appkey,
                'appsecret': appsecret}
        res = self.request.getData(url=url, data=data, headers=headers)
        if res['errcode'] == 0:
            return res['access_token'] #'d258a449d3c831e783acb7db0126be96'
        else:
            print('token获取失败')
            return None



    # 上传文件，获取media_id
    # filePath 文件路径
    def getMedia_id(self, filePath):  # 拿到接口凭证
        url = 'https://oapi.dingtalk.com/media/upload?access_token=%s&type=file' % self.access_token
        files = {'media': open(filePath, 'rb')}
        data = {'access_token': self.access_token,
                'type': 'file'}

        res = self.request.postFormData(url=url, files=files, data=data)

        if res['errcode'] == 0:
            return res["media_id"]
        else:
            print('获取medie_id失败')
            return None

    # 发送文件到指定群
    # filePath 文件路径
    # chatId 群id 通过jsapi工具获取的群聊id  https://wsdebug.dingtalk.com/
    def SendFile(self, filePath, chatId):
        media_id = self.getMedia_id(filePath)

        url = 'https://oapi.dingtalk.com/chat/send?access_token=' + self.access_token
        header = {
            'Content-Type': 'application/json'
        }
        data = {'access_token': self.access_token,
                'chatid': chatId,
                'msg': {
                    'msgtype': 'file',
                    'file': {'media_id': media_id}
                }}
        res = self.request.postJsonData(url=url, json=data, headers=header) #requests.request('POST', url, data=json.dumps(data), headers=header)
        if res['errcode'] == 0:
            print(filePath, '文件发送成功')
        else:
            print(filePath, '文件发送失败')


agentId = '1144185570'
appkey = 'dingb4zcg5o8ubkciavn'
appsecret = 'ff1dujPLmdGQAU19TJKKzxET96eIGHGzjny9XuxLNGh6LtSBRdfQZXuXWOdtNwTH'
chatId = 'chat7de921003c27badb1c9cc3b9d05ad7b8'
dt = DingTalk2(appkey, appsecret)
# res = dt.getMedia_id(filePath='/Users/xuxiang/Downloads/APScheduler.py')
# res = dt.SendFile(filePath='/Users/xuxiang/Downloads/APScheduler.py', chatId='chat7de921003c27badb1c9cc3b9d05ad7b8')
# res = dt.send_text_msg(chatId=chatId, content='测试测试')
res = dt.getChat(chatId)
print(res)